@@ -1,5 +1,5 @@
 package HackaMol::Roles::FileFetchRole;
-$HackaMol::Roles::FileFetchRole::VERSION = '0.042';
+$HackaMol::Roles::FileFetchRole::VERSION = '0.043';
 #ABSTRACT: Role for using LWP::Simple to fetch files from www 
 use Moose::Role;
 use Carp;
@@ -22,8 +22,15 @@ sub get_pdbid{
   #return pdb contents downloaded from pdb.org
   my $self = shift;
   my $pdbid = _fix_pdbid(shift);  
-  my $pdb = HTTP::Tiny->new->get($self->pdbserver.$pdbid);
-  return ( $pdb->{content} );
+  my ($ok, $why) = HTTP::Tiny->can_ssl;
+  if ($ok){
+    my $pdb = HTTP::Tiny->new->get($self->pdbserver.$pdbid);
+    return ( $pdb->{content} );
+  }
+  else {
+    warn "$why";
+    return 0;
+  }
 }
 
 sub getstore_pdbid{
@@ -36,11 +43,18 @@ sub getstore_pdbid{
 
   if ($fpdbid->exists and not $self->overwrite){
     carp "$fpdbid exists, set self->overwrite(1) to overwrite";
-    return $fpdbid->slurp;
+    return $fpdbid->stringify;
   }
   my $pdb = $self->get_pdbid( $pdbid );
-  $fpdbid->spew($pdb);
-  return ( $pdb );
+  
+  if ($pdb){
+    $fpdbid->spew($pdb);
+    return ( $fpdbid->stringify );
+  }
+  else{
+    warn "could not connect, $fpdbid not written\n";
+    return 0;
+  }
 }
 
 no Moose::Role;
@@ -56,7 +70,7 @@ HackaMol::Roles::FileFetchRole - Role for using LWP::Simple to fetch files from
 
 =head1 VERSION
 
-version 0.042
+version 0.043
 
 =head1 SYNOPSIS
 
